@@ -187,6 +187,24 @@ LinternaMagica.prototype.create_video_object = function(object_data)
     if (object_data.link)
     {
 	var mime = object_data.mime ? object_data.mime : "video/flv";
+
+ 	// Fix for video/mp4 (and other QuickTime clips) for
+	// totemNarrowSpace plugin. Fixes these issues of
+	// totemNarrowSpace plugin:
+	// - No API for fullscreen. 
+	// - The UA it sends is different from the browser, Vimeo does
+	// not load.
+	// With video/flv totemCone plugin will load.
+	if (/mp4|m4v|quicktime/i)
+	{
+	    var mp4 = navigator.mimeTypes["video/mp4"];
+	    if (mp4 && mp4.enabledPlugin && mp4.enabledPlugin.name &&
+		/totem/i.test(mp4.enabledPlugin.description))
+	    {
+		mime = "video/flv";
+	    }
+	}
+
 	object_tag.setAttribute("type", mime);
 	object_tag.setAttribute("data", object_data.link);
     }
@@ -321,6 +339,15 @@ LinternaMagica.prototype.create_video_object = function(object_data)
 				  (this.controls ? 24 : 0))+"px"),
 				"important");
 
+    // In channels/user pages in YouTube the web controlls are
+    // overlapped by this element.
+    if (/youtube\.com/i.test(window.location.hostname) &&
+	document.getElementById("playnav-playview"))
+    {
+	var el = 	document.getElementById("playnav-playview");
+	el.style.setProperty("margin-top", "50px", "important");
+    }
+
     // The thumbnail image overlaps the toggle plugin button after our
     // changes. This way our button is visible.
     if (/vimeo\.com/i.test(window.location.hostname) && 
